@@ -1,6 +1,6 @@
 ;;; cider-client.el --- A layer of abstraction above low-level nREPL client code. -*- lexical-binding: t -*-
 
-;; Copyright © 2013-2024 Bozhidar Batsov
+;; Copyright © 2013-2025 Bozhidar Batsov
 ;;
 ;; Author: Bozhidar Batsov <bozhidar@batsov.dev>
 
@@ -108,7 +108,7 @@ EVAL-BUFFER is the buffer where the spinner was started."
 ;;; Evaluation helpers
 (defun cider-ns-form-p (form)
   "Check if FORM is an ns form."
-  (string-match-p "^[[:space:]]*\(ns\\([[:space:]]*$\\|[[:space:]]+\\)" form))
+  (string-match-p "\\`[[:space:]]*\(ns\\([[:space:]]*$\\|[[:space:]]+\\)" form))
 
 (defun cider-ns-from-form (ns-form)
   "Get ns substring from NS-FORM."
@@ -189,16 +189,20 @@ the current connection.  Return the id of the sent message.
 If TOOLING is truthy then the tooling session is used."
   (nrepl-send-request request callback (or connection (cider-current-repl 'any 'ensure)) tooling))
 
-(defun cider-nrepl-send-sync-request (request &optional connection abort-on-input)
+(defun cider-nrepl-send-sync-request (request &optional connection
+                                              abort-on-input callback)
   "Send REQUEST to the nREPL server synchronously using CONNECTION.
 Hold till final \"done\" message has arrived and join all response messages
 of the same \"op\" that came along and return the accumulated response.
 If ABORT-ON-INPUT is non-nil, the function will return nil
 at the first sign of user input, so as not to hang the
-interface."
+interface.
+if CALLBACK is non-nil, it will additionally be called on all received messages."
   (nrepl-send-sync-request request
                            (or connection (cider-current-repl 'any 'ensure))
-                           abort-on-input))
+                           abort-on-input
+                           nil
+                           callback))
 
 (defun cider-nrepl-send-unhandled-request (request &optional connection)
   "Send REQUEST to the nREPL CONNECTION and ignore any responses.
@@ -245,15 +249,15 @@ Assuming this is the Clojure map you want to use as `cljfmt' options:
 
 you need to encode it as the following plist:
 
-  '((\"indents\" ((\"org.me/foo\" ((\"inner\" 0))))) (\"alias-map\" ((\"me\" \"org.me\"))))"
-  :type 'list
+  \\='((\"indents\" ((\"org.me/foo\" ((\"inner\" 0))))) (\"alias-map\" ((\"me\" \"org.me\"))))"
+  :type '(repeat sexp)
   :group 'cider
   :package-version '(cider . "1.1.0"))
 
-(defun cider--nrepl-format-code-request-map (&optional format-options)
+(defun cider--nrepl-format-code-request-options (&optional format-options)
   "Map to merge into requests that require code formatting.
 If non-nil, FORMAT-OPTIONS specifies the options cljfmt will use to format
-the code.  See `cider-format-code-options` for details."
+the code.  See `cider-format-code-options' for details."
   (when format-options
     (let* ((indents-dict (when (assoc "indents" format-options)
                            (thread-last
@@ -267,15 +271,11 @@ the code.  See `cider-format-code-options` for details."
                                (map-pairs)
                                (seq-mapcat #'identity)
                                (apply #'nrepl-dict)))))
-      (thread-last
-        (map-merge 'list
-                   (when indents-dict
-                     `(("indents" ,indents-dict)))
-                   (when alias-map-dict
-                     `(("alias-map" ,alias-map-dict))))
-        (map-pairs)
-        (seq-mapcat #'identity)
-        (apply #'nrepl-dict)))))
+      (nrepl-dict
+       `(,@(when indents-dict
+             `("indents" ,indents-dict))
+         ,@(when alias-map-dict
+             `("alias-map" ,alias-map-dict)))))))
 
 (defcustom cider-print-fn 'pprint
   "Sets the function to use for printing.
@@ -316,14 +316,11 @@ nil."
   "A map of options that will be passed to `cider-print-fn'.
 Here's an example for `pprint':
 
-  '((\"length\" 50) (\"right-margin\" 70))"
-  :type 'list
+  \\='((\"length\" 50) (\"right-margin\" 70))"
+  :type '(repeat sexp)
   :group 'cider
   :package-version '(cider . "0.21.0"))
 
-(make-obsolete-variable 'cider-pprint-fn 'cider-print-fn "0.21")
-(make-obsolete-variable 'cider-pprint-options 'cider-print-options "0.21")
-
 (defcustom cider-print-quota (* 1024 1024)
   "A hard limit on the number of bytes to return from any printing operation.
 Set to nil for no limit."
@@ -342,6 +339,17 @@ The default value in nREPL is 1024."
   :group 'cider
   :package-version '(cider . "0.25.0"))
 
+(defcustom cider-download-java-sources t
+  "Whether to automatically download source artifacts for 3rd-party Java classes.
+
+When enabled, CIDER will attempt to download source JARs from Maven for
+Java classes if the source file is not found locally.  This downloading only
+happens once per artifact, and only when the user jumps to definition or
+requests `cider-doc' on a Java class or a member of the class."
+  :type 'boolean
+  :group 'cider
+  :package-version '(cider . "1.17.1"))
+
 (defun cider--print-fn ()
   "Return the value to send in the nrepl.middleware.print/print slot."
   (pcase cider-print-fn
@@ -373,7 +381,7 @@ The result will be a string."
          (result (cdr (assoc printer (cadr (assoc name cider--print-options-mapping))))))
     (symbol-name (or result name))))
 
-(defun cider--nrepl-print-request-map (&optional right-margin)
+(defun cider--nrepl-print-request-plist (&optional right-margin)
   "Map to merge into requests that require pretty-printing.
 RIGHT-MARGIN specifies the maximum column-width of the printed result, and
 is included in the request if non-nil."
@@ -385,35 +393,29 @@ is included in the request if non-nil."
                           (map-pairs)
                           (seq-mapcat #'identity)
                           (apply #'nrepl-dict))))
-    (map-merge 'list
-               `(("nrepl.middleware.print/stream?" "1"))
-               (when cider-print-fn
-                 `(("nrepl.middleware.print/print" ,(cider--print-fn))))
-               (when cider-print-quota
-                 `(("nrepl.middleware.print/quota" ,cider-print-quota)))
-               (when cider-print-buffer-size
-                 `(("nrepl.middleware.print/buffer-size" ,cider-print-buffer-size)))
-               (unless (nrepl-dict-empty-p print-options)
-                 `(("nrepl.middleware.print/options" ,print-options))))))
+    `("nrepl.middleware.print/stream?" "1"
+      ,@(when cider-print-fn
+          `("nrepl.middleware.print/print" ,(cider--print-fn)))
+      ,@(when cider-print-quota
+          `("nrepl.middleware.print/quota" ,cider-print-quota))
+      ,@(when cider-print-buffer-size
+          `("nrepl.middleware.print/buffer-size" ,cider-print-buffer-size))
+      ,@(unless (nrepl-dict-empty-p print-options)
+          `("nrepl.middleware.print/options" ,print-options)))))
 
-(defun cider--nrepl-pr-request-map ()
+(defun cider--nrepl-pr-request-plist ()
   "Map to merge into requests that do not require pretty printing."
   (let ((print-options (thread-last
                          cider-print-options
                          (map-pairs)
                          (seq-mapcat #'identity)
                          (apply #'nrepl-dict))))
-    (map-merge 'list
-               `(("nrepl.middleware.print/print" "cider.nrepl.pprint/pr")
-                 ("nrepl.middleware.print/stream?" nil))
-               (unless (nrepl-dict-empty-p print-options)
-                 `(("nrepl.middleware.print/options" ,print-options)))
-               (when cider-print-quota
-                 `(("nrepl.middleware.print/quota" ,cider-print-quota))))))
-
-(defun cider--nrepl-content-type-map ()
-  "Map to be merged into an eval request to make it use content-types."
-  '(("content-type" "true")))
+    `("nrepl.middleware.print/print" "cider.nrepl.pprint/pr"
+      "nrepl.middleware.print/stream?" nil
+      ,@(unless (nrepl-dict-empty-p print-options)
+          `("nrepl.middleware.print/options" ,print-options))
+      ,@(when cider-print-quota
+          `("nrepl.middleware.print/quota" ,cider-print-quota)))))
 
 (defun cider-tooling-eval (input callback &optional ns connection)
   "Send the request INPUT to CONNECTION and register the CALLBACK.
@@ -667,6 +669,7 @@ CONTEXT represents a completion context for compliment."
                                     "ns" ,(cider-current-ns)
                                     "prefix" ,prefix
                                     "context" ,context
+                                    "sort-order" "by-name"
                                     ,@(when cider-enhanced-cljs-completion-p '("enhanced-cljs-completion?" "t")))
                                   (cider-nrepl-send-sync-request (cider-current-repl)
                                                                  'abort-on-input))))
@@ -681,13 +684,25 @@ CONTEXT represents a completion context for compliment."
 
 (defun cider-sync-request:info (symbol &optional class member context)
   "Send \"info\" op with parameters SYMBOL or CLASS and MEMBER, honor CONTEXT."
-  (let ((var-info (thread-first `("op" "info"
-                                  "ns" ,(cider-current-ns)
-                                  ,@(when symbol `("sym" ,symbol))
-                                  ,@(when class `("class" ,class))
-                                  ,@(when member `("member" ,member))
-                                  ,@(when context `("context" ,context)))
-                                (cider-nrepl-send-sync-request (cider-current-repl)))))
+  (let* ((req
+          `("op" "info"
+            "ns" ,(cider-current-ns)
+            ,@(when symbol `("sym" ,symbol))
+            ,@(when class `("class" ,class))
+            ,@(when member `("member" ,member))
+            ,@(when context `("context" ,context))
+            ,@(when cider-download-java-sources `("download-sources-jar" "1"))))
+         (callback
+          (lambda (resp)
+            (let ((status (nrepl-dict-get resp "status"))
+                  (coords (nrepl-dict-get resp "coords")))
+              (when (member "download-sources-jar" status)
+                (message "Local source not found, downloading Java sources for artifact %s/%s %s..."
+                         (nrepl-dict-get coords "group")
+                         (nrepl-dict-get coords "artifact")
+                         (nrepl-dict-get coords "version"))))))
+         (var-info
+          (cider-nrepl-send-sync-request req (cider-current-repl) nil callback)))
     (if (member "no-info" (nrepl-dict-get var-info "status"))
         nil
       var-info)))
@@ -850,7 +865,7 @@ The result entries are relative to the classpath."
   "Perform nREPL \"format-code\" op with CODE.
 FORMAT-OPTIONS is an optional configuration map for cljfmt."
   (let* ((request `("op" "format-code"
-                    "options" ,(cider--nrepl-format-code-request-map format-options)
+                    "options" ,(cider--nrepl-format-code-request-options format-options)
                     "code" ,code))
          (response (cider-nrepl-send-sync-request request))
          (err (nrepl-dict-get response "err")))
@@ -862,12 +877,9 @@ FORMAT-OPTIONS is an optional configuration map for cljfmt."
 
 (defun cider-sync-request:format-edn (edn right-margin)
   "Perform \"format-edn\" op with EDN and RIGHT-MARGIN."
-  (let* ((request (thread-last
-                    (map-merge 'list
-                               `(("op" "format-edn")
-                                 ("edn" ,edn))
-                               (cider--nrepl-print-request-map right-margin))
-                    (seq-mapcat #'identity)))
+  (let* ((request `("op" "format-edn"
+                    "edn" ,edn
+                    ,@(cider--nrepl-print-request-plist right-margin)))
          (response (cider-nrepl-send-sync-request request))
          (err (nrepl-dict-get response "err")))
     (when err
