@@ -1,6 +1,6 @@
 ;;; cider-connection.el --- Connection and session life-cycle management for CIDER -*- lexical-binding: t -*-
 ;;
-;; Copyright © 2019-2024 Artur Malabarba, Bozhidar Batsov, Vitalie Spinu and CIDER contributors
+;; Copyright © 2019-2025 Artur Malabarba, Bozhidar Batsov, Vitalie Spinu and CIDER contributors
 ;;
 ;; Author: Artur Malabarba <bruce.connor.am@gmail.com>
 ;;         Bozhidar Batsov <bozhidar@batsov.dev>
@@ -69,7 +69,7 @@ Useful for switching between alternative minor modes like `inf-clojure-mode'."
   :package-version '(cider . "0.9.0"))
 
 (defcustom cider-merge-sessions nil
-  "Controls session combination behaviour.
+  "Controls session combination behavior.
 
 Symbol `host' combines all sessions of a project associated with the same host.
 Symbol `project' combines all sessions of a project.
@@ -264,7 +264,7 @@ We look only at the major and minor components.  When the major
 version is 0, only check that the minor versions match.  When the major version
 is > 0, first check that the major version matches, then that the minor
 version is >= the required minor version.
-VER the 'installed' version,
+VER the `installed' version,
 REQUIRED-VER the version required by cider."
   (let ((ver* (cider--strip-version-patch ver))
         (required-ver* (cider--strip-version-patch required-ver)))
@@ -785,7 +785,7 @@ Session name can be customized with `cider-session-name-template'."
 ;;; REPL Buffer Init
 
 (defvar-local cider-cljs-repl-type nil
-  "The type of the ClojureScript runtime ('browser, 'node, 'figwheel, etc.).")
+  "The type of the ClojureScript runtime (\\='browser, \\='node, \\='figwheel, etc.).")
 
 (defvar-local cider-repl-type nil
   "The type of this REPL buffer, usually either clj or cljs.")
@@ -938,6 +938,12 @@ function with the repl buffer set as current."
     (user-error "No %s REPLs in current session \"%s\""
                 type (car (sesman-current-session 'CIDER)))))
 
+(defvar-local cider--ancillary-buffer-repl nil
+  "Special buffer-local variable that contains reference to the REPL connection.
+This should be set in ancillary CIDER buffers that originate from some
+event (e.g. *cider-inspector*, *cider-error*) and which never change the
+REPL (connection) which produced them.")
+
 (defun cider-current-repl (&optional type ensure)
   "Get the most recent REPL of TYPE from the current session.
 TYPE is either clj, cljs, multi or any.
@@ -951,17 +957,18 @@ no linked session or there is no REPL of TYPE within the current session."
                  (eq cider-repl-type type)))
         ;; shortcut when in REPL buffer
         (current-buffer)
-      (let* ((type (or type (cider-repl-type-for-buffer)))
-             (repls (cider-repls type ensure))
-             (repl (if (<= (length repls) 1)
-                       (car repls)
-                     ;; pick the most recent one
-                     (seq-find (lambda (b)
-                                 (member b repls))
-                               (buffer-list)))))
-        (if (and ensure (null repl))
-            (cider--no-repls-user-error type)
-          repl)))))
+      (or cider--ancillary-buffer-repl
+          (let* ((type (or type (cider-repl-type-for-buffer)))
+                 (repls (cider-repls type ensure))
+                 (repl (if (<= (length repls) 1)
+                           (car repls)
+                         ;; pick the most recent one
+                         (seq-find (lambda (b)
+                                     (member b repls))
+                                   (buffer-list)))))
+            (if (and ensure (null repl))
+                (cider--no-repls-user-error type)
+              repl))))))
 
 (defun cider--match-repl-type (type buffer)
   "Return non-nil if TYPE matches BUFFER's REPL type."
