@@ -1,6 +1,6 @@
 ;;; cider-log.el --- Log inspection functionality for Clojure -*- lexical-binding: t -*-
 
-;; Copyright © 2023-2024 Bozhidar Batsov and CIDER contributors
+;; Copyright © 2023-2025 Bozhidar Batsov and CIDER contributors
 
 ;; Author: r0man <roman@burningswell.com>
 
@@ -48,6 +48,20 @@ Example values: \"Logback\", \"Timbre\"."
   :safe #'stringp
   :type 'string)
 
+(defcustom cider-log-frameworks-buffer "*cider-log-frameworks*"
+  "The name of the log frameworks popup buffer."
+  :group 'cider
+  :package-version '(cider . "1.17")
+  :safe #'stringp
+  :type 'string)
+
+(defcustom cider-log-auto-select-frameworks-buffer t
+  "Whether to auto-select the log frameworks popup buffer."
+  :group 'cider
+  :package-version '(cider . "1.17")
+  :safe #'booleanp
+  :type 'boolean)
+
 (defcustom cider-log-appender-id "cider-log"
   "The name of the default log appender."
   :group 'cider
@@ -201,15 +215,6 @@ It will not be used if the package hasn't been installed."
                   "filters" ,(cider-log-consumer-filters consumer))
                 (cider-nrepl-send-request callback)))
 
-(defun cider-request:log-analyze-stacktrace (framework appender event &optional callback)
-  "Analyze the EVENT stacktrace of the APPENDER of FRAMEWORK and call CALLBACK."
-  (cider-ensure-op-supported "cider/log-analyze-stacktrace")
-  (thread-first `("op" "cider/log-analyze-stacktrace"
-                  "framework" ,(cider-log-framework-id framework)
-                  "appender" ,(cider-log-appender-id appender)
-                  "event" ,(cider-log-event-id event))
-                (cider-nrepl-send-request callback)))
-
 (defun cider-sync-request:log-update-consumer (framework appender consumer)
   "Add CONSUMER to the APPENDER of FRAMEWORK and call CALLBACK on log events."
   (cider-ensure-op-supported "cider/log-update-consumer")
@@ -268,13 +273,11 @@ It will not be used if the package hasn't been installed."
   "Format the log EVENT from the APPENDER of the log FRAMEWORK."
   (cider-ensure-op-supported "cider/log-format-event")
   (thread-first
-    (seq-mapcat #'identity
-                (map-merge 'list
-                           (cider--nrepl-print-request-map fill-column)
-                           `(("op" "cider/log-format-event")
-                             ("framework" ,(cider-log-framework-id framework))
-                             ("appender" ,(cider-log-appender-id appender))
-                             ("event" ,(cider-log-event-id event)))))
+    `("op" "cider/log-format-event"
+      "framework" ,(cider-log-framework-id framework)
+      "appender" ,(cider-log-appender-id appender)
+      "event" ,(cider-log-event-id event)
+      ,@(cider--nrepl-print-request-plist fill-column))
     (cider-nrepl-send-sync-request)
     (nrepl-dict-get "cider/log-format-event")))
 
@@ -678,24 +681,6 @@ The KEYS are used to lookup the values and are joined by SEPARATOR."
       (seq-doseq (window windows)
         (set-window-point window (point-max))))))
 
-(defun cider-log-event--show-stacktrace (framework appender event)
-  "Show the stacktrace of the log EVENT of FRAMEWORK and APPENDER."
-  (when (and framework appender event (cider-log-event-exception event))
-    (let ((auto-select-buffer cider-auto-select-error-buffer)
-          (causes nil))
-      (cider-request:log-analyze-stacktrace
-       framework appender event
-       (lambda (response)
-         (nrepl-dbind-response response (class status)
-           (cond (class  (setq causes (cons response causes)))
-                 (status (when causes
-                           (cider-stacktrace-render
-                            (cider-popup-buffer cider-error-buffer
-                                                auto-select-buffer
-                                                #'cider-stacktrace-mode
-                                                'ancillary)
-                            (reverse causes)))))))))))
-
 (defun cider-log-event-next-line (&optional n)
   "Move N lines forward."
   (interactive "p")
@@ -707,8 +692,6 @@ The KEYS are used to lookup the values and are joined by SEPARATOR."
                (event (cider-log-event-at-point)))
       (let ((cider-auto-select-error-buffer nil))
         (save-window-excursion
-          (when (get-buffer-window cider-error-buffer)
-            (cider-log-event--show-stacktrace framework appender event))
           (when (get-buffer-window cider-inspector-buffer)
             (cider-log-event--inspect framework appender event))
           (when (get-buffer-window cider-log-event-buffer)
@@ -844,7 +827,6 @@ The KEYS are used to lookup the values and are joined by SEPARATOR."
     (define-key map (kbd "C-c M-l f") #'cider-log-framework)
     (define-key map (kbd "C-c M-l i") #'cider-log-info)
     (define-key map (kbd "C-c M-l l") #'cider-log)
-    (define-key map (kbd "E") 'cider-log-show-stacktrace)
     (define-key map (kbd "F") 'cider-log-print-event)
     (define-key map (kbd "I") 'cider-log-inspect-event)
     (define-key map (kbd "RET") 'cider-log-inspect-event)
@@ -1032,6 +1014,26 @@ the CIDER Inspector and the CIDER stacktrace mode.
 
 ;; Framework actions
 
+(transient-define-suffix cider-log-show-frameworks ()
+  "Show the available log frameworks in a buffer."
+  :description "Show frameworks in a buffer"
+  (interactive)
+  (let ((frameworks (cider-sync-request:log-frameworks)))
+    (with-current-buffer (cider-popup-buffer cider-log-frameworks-buffer
+                                             cider-log-auto-select-frameworks-buffer)
+      (read-only-mode -1)
+      (insert (with-temp-buffer
+                (insert (propertize (cider-propertize "Cider Log Frameworks" 'ns) 'ns t) "\n\n")
+                (dolist (framework frameworks)
+                  (insert (propertize (cider-propertize (cider-log-framework-name framework) 'ns) 'ns t) "\n\n")
+                  (insert (format "  Website ......... %s\n" (cider-log-framework-website-url framework)))
+                  (insert (format "  Javadocs ........ %s\n" (cider-log-framework-javadoc-url framework)))
+                  (insert (format "  Levels .......... %s\n" (string-join (cider-log-framework-level-names framework) ", ")))
+                  (newline))
+                (buffer-string)))
+      (read-only-mode 1)
+      (goto-char (point-min)))))
+
 (transient-define-suffix cider-log-browse-javadocs (framework)
   "Browse the Javadoc of the log FRAMEWORK."
   :description "Browse Java documentation"
@@ -1141,16 +1143,12 @@ the CIDER Inspector and the CIDER stacktrace mode.
            (cider-log-appender-display-name appender)))
 
 ;; Event actions
-
-(transient-define-suffix cider-log-show-stacktrace (framework appender event)
-  "Show the stacktrace of the log EVENT of FRAMEWORK and APPENDER."
-  :description "Show log event stacktrace"
-  :if #'cider-log-event-at-point
-  :inapt-if-not (lambda ()
-                  (when-let (event (cider-log-event-at-point))
-                    (cider-log-event-exception event)))
-  (interactive (list (cider-log--framework) (cider-log--appender) (cider-log-event-at-point)))
-  (cider-log-event--show-stacktrace framework appender event))
+(defun cider-log-show-stacktrace (&rest _)
+  "Removed."
+  (interactive)
+  (message "This function has been removed.
+You can jump to functions and methods directly from the printed stacktrace now."))
+(make-obsolete 'cider-log-show-stacktrace nil "1.18")
 
 (transient-define-suffix cider-log-print-event (framework appender event)
   "Format the log EVENT of FRAMEWORK and APPENDER."
@@ -1220,6 +1218,7 @@ the CIDER Inspector and the CIDER stacktrace mode.
 (transient-define-prefix cider-log-framework (framework)
   "Show the Cider log framework menu."
   [["Cider Log Framework\n\nActions:"
+    ("a" cider-log-show-frameworks)
     ("b" cider-log-set-buffer)
     ("j" cider-log-browse-javadocs)
     ("s" cider-log-set-framework)
@@ -1406,7 +1405,6 @@ the CIDER Inspector and the CIDER stacktrace mode.
    (cider-log--threads-option)]
   ["Actions"
    ("c" cider-log-clear-event-buffer)
-   ("e" cider-log-show-stacktrace)
    ("i" cider-log-inspect-event)
    ("p" cider-log-print-event)
    ("s" cider-log--do-search-events)]
@@ -1441,6 +1439,7 @@ based on `transient-mode'."
 (transient-define-prefix cider-log (framework appender)
   "Show the Cider log menu."
   [["Framework Actions"
+    ("fa" cider-log-show-frameworks)
     ("fs" cider-log-set-framework)
     ("fb" cider-log-set-buffer)
     ("fj" cider-log-browse-javadocs)
@@ -1463,7 +1462,6 @@ based on `transient-mode'."
    ["Event Actions"
     ("eb" cider-log-switch-to-buffer)
     ("ec" cider-log-clear-event-buffer)
-    ("ee" cider-log-show-stacktrace)
     ("ei" cider-log-inspect-event)
     ("ep" cider-log-print-event)
     ("es" "Search log events" cider-log-event-search
